==> apache-johnzon-1.2.21-src.tar.gz: apache-johnzon-1.2.21-src/johnzon-jsonb/src/main/java/org/apache/johnzon/jsonb/api/experimental/JsonbExtension.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.johnzon.jsonb.api.experimental;

import java.lang.reflect.Type;

import javax.json.JsonValue;
import javax.json.stream.JsonGenerator;
import javax.json.stream.JsonParser;

public interface JsonbExtension {
    // https://github.com/eclipse-ee4j/jsonb-api/issues/111

    <T> T fromJsonValue(JsonValue json, Class<T> type);

    <T> T fromJsonValue(JsonValue json, Type runtimeType);

    JsonValue toJsonValue(Object object);

    JsonValue toJsonValue(Object object, Type runtimeType);

    // https://github.com/eclipse-ee4j/jsonb-api/issues/224



    <T> T fromJson(JsonParser json, Class<T> type);

    <T> T fromJson(JsonParser json, Type runtimeType);

    void toJson(Object object, JsonGenerator jsonGenerator);

    void toJson(Object object, Type runtimeType, JsonGenerator jsonGenerator);
}

==> apache-johnzon-2.0.0-src.tar.gz: apache-johnzon-2.0.0-src/johnzon-jsonb/src/main/java/org/apache/johnzon/jsonb/api/experimental/JsonbExtension.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.johnzon.jsonb.api.experimental;

import java.lang.reflect.Type;

import jakarta.json.JsonValue;
import jakarta.json.stream.JsonGenerator;
import jakarta.json.stream.JsonParser;

public interface JsonbExtension {
    // https://github.com/eclipse-ee4j/jsonb-api/issues/111

    <T> T fromJsonValue(JsonValue json, Class<T> type);

    <T> T fromJsonValue(JsonValue json, Type runtimeType);

    JsonValue toJsonValue(Object object);

    JsonValue toJsonValue(Object object, Type runtimeType);

    // https://github.com/eclipse-ee4j/jsonb-api/issues/224



    <T> T fromJson(JsonParser json, Class<T> type);

    <T> T fromJson(JsonParser json, Type runtimeType);

    void toJson(Object object, JsonGenerator jsonGenerator);

    void toJson(Object object, Type runtimeType, JsonGenerator jsonGenerator);
}
